@@ -361,7 +361,7 @@ class CatmullRom(Curve):
                 ret.append(Line(self.id + f"_{ii}", start, end))
         return ret
 
-    def compute_catmull_points(self, vertices: List[Vector2], numPoints=None):
+    def compute_catmull_points(self, vertices, numPoints=None):
         if numPoints is None:
             numPoints = 30
         if numPoints < 2 or len(vertices) < 4:
@@ -373,10 +373,11 @@ class CatmullRom(Curve):
         c = []
         for ii in range(len(vertices) - 3):
             # Convert the points to numpy so that we can do array multiplication
-            P0, P1, P2, P3 = map(np.array, [(self.control_points[ii].x, self.control_points[ii].y),
-                                            (self.control_points[ii + 1].x, self.control_points[ii + 1].y),
-                                            (self.control_points[ii + 2].x, self.control_points[ii + 2].y),
-                                            (self.control_points[ii + 3].x, self.control_points[ii + 3].y)])
+            # P0, P1, P2, P3 = map(np.array, [(self.control_points[ii].x, self.control_points[ii].y),
+            #                                 (self.control_points[ii + 1].x, self.control_points[ii + 1].y),
+            #                                 (self.control_points[ii + 2].x, self.control_points[ii + 2].y),
+            #                                 (self.control_points[ii + 3].x, self.control_points[ii + 3].y)])
+            P0, P1, P2, P3 = map(np.array, [vertices[ii], vertices[ii + 1], vertices[ii + 2], vertices[ii + 3]])
 
             # Parametric constant: 0.5 for the centripetal spline, 0.0 for the uniform spline, 1.0 for the chordal spline.
             alpha = 0.5
@@ -495,7 +496,7 @@ class CurveBuilder:
         elif curve_type == CurveType.CATMULLROM:
             leftover_count = len(points) if len(points) < 4 else 0
             leftover_points = points if leftover_count != 0 else leftover_points
-            used_points = points if leftover_count != 0 else points
+            used_points = points if leftover_count == 0 else []
             curves = self.catmullrom_from_points(used_points)
 
         return curves, leftover_points
@@ -534,7 +535,7 @@ class CurveBuilder:
     def catmullrom_from_points(self, points):
         curves = []
 
-        if len(points) < 3:
+        if len(points) < 4:
             return curves
 
         # A Cubic Bezier requires 4 control points, so operate in blocks of 3 (re-using the last each time)
@@ -579,7 +580,6 @@ if __name__ == "__main__":
     curves, leftover = builder.curves_from_points(curve_type=CurveType.CATMULLROM, points=points)
 
     curve = curves[0]
-    print(curve.control_points)
-    catmullpoints = curves[0].compute_catmull_points(curves[0].control_points)
+    catmullpoints = curve.compute_catmull_points([(x.x, x.y) for x in curve.control_points])
     print(catmullpoints)
 
